@@ -111,7 +111,7 @@ sub GSL_MATRIX_SWAP : Tests {
    map { gsl_matrix_set($self->{matrix}, $_,$_, $_ ** 2) } (0..4);
    my $matrix = gsl_matrix_alloc(5,5);
    map { gsl_matrix_set($matrix, $_,$_, $_) } (0..4);
-   ok_status(gsl_matrix_swap($self->{matrix}, $matrix), $GSL_SUCCESS);
+   ok_status(gsl_matrix_swap($self->{matrix}, $matrix));
 
    my @got = map { gsl_matrix_get($self->{matrix}, $_, $_) } (0..4);
    map { is($got[$_], $_) } (0..4);
@@ -123,7 +123,7 @@ sub GSL_MATRIX_MEMCPY : Tests {
    my $self = shift;
    my $matrix = gsl_matrix_alloc(5,5);
    map { gsl_matrix_set($self->{matrix}, $_,$_, $_ ** 2) } (0..4);
-   ok_status(gsl_matrix_memcpy($matrix, $self->{matrix}), $GSL_SUCCESS);
+   ok_status(gsl_matrix_memcpy($matrix, $self->{matrix}));
    ok_similar( [ map { gsl_matrix_get($matrix, $_, $_) } (0..4) ], 
                [ map {  $_** 2 } (0..4)                        ]
    );  
@@ -133,7 +133,7 @@ sub GSL_MATRIX_SWAP_ROWS : Tests {
    my $self = shift; 
    map { gsl_matrix_set($self->{matrix}, 0,$_, $_) } (0..4);
    map { gsl_matrix_set($self->{matrix}, 1,$_, 3) } (0..4);
-   ok_status(gsl_matrix_swap_rows($self->{matrix}, 0, 1), $GSL_SUCCESS);
+   ok_status(gsl_matrix_swap_rows($self->{matrix}, 0, 1));
    my @got = map { gsl_matrix_get($self->{matrix}, 1, $_) } (0..4);
    map { is($got[$_], $_) } (0..4);   
    @got = map { gsl_matrix_get($self->{matrix}, 0, $_) } (0..4);
@@ -144,7 +144,7 @@ sub GSL_MATRIX_SWAP_COLUMNS : Tests {
    my $self = shift;
    map { gsl_matrix_set($self->{matrix}, $_,0, $_) } (0..4);
    map { gsl_matrix_set($self->{matrix}, $_,1, 3) } (0..4);
-   ok_status(gsl_matrix_swap_columns($self->{matrix}, 0, 1), $GSL_SUCCESS);
+   ok_status(gsl_matrix_swap_columns($self->{matrix}, 0, 1));
    my @got = map { gsl_matrix_get($self->{matrix}, $_, 1) } (0..4);
    map { is($got[$_], $_) } (0..4);   
    @got = map { gsl_matrix_get($self->{matrix}, $_, 0) } (0..4);
@@ -155,7 +155,7 @@ sub GSL_MATRIX_SWAP_ROWCOL : Tests {
    my $self = shift;
    map { gsl_matrix_set($self->{matrix}, 0,$_, $_) } (0..4);
    map { gsl_matrix_set($self->{matrix}, $_,2, 2) } (0..4);
-   ok_status(gsl_matrix_swap_rowcol($self->{matrix}, 0, 2), $GSL_SUCCESS);
+   ok_status(gsl_matrix_swap_rowcol($self->{matrix}, 0, 2));
    
    my @got = map { gsl_matrix_get($self->{matrix}, $_, 2) } (0..4);
    is_deeply( [ @got ], [ qw/2 1 0 3 4/  ] );
@@ -168,7 +168,7 @@ sub GSL_MATRIX_TRANSPOSE_MEMCPY : Tests {
    my $self = shift;
    map { gsl_matrix_set($self->{matrix}, 0,$_, $_) } (0..4);
    my $matrix = gsl_matrix_alloc(5,5); 
-   ok_status(gsl_matrix_transpose_memcpy($matrix, $self->{matrix}), $GSL_SUCCESS);   
+   ok_status(gsl_matrix_transpose_memcpy($matrix, $self->{matrix}));   
    my @got = map { gsl_matrix_get($matrix, $_, 0) } (0..4);
    map { is($got[$_], $_) } (0..4);
 }
@@ -347,25 +347,25 @@ sub GSL_MATRIX_ISNONNEG : Tests {
 
 sub GSL_MATRIX_GET_ROW : Tests {
    my $self = shift;
-   my $vector->{vector} = gsl_vector_alloc(5);
+   my $vector = gsl_vector_alloc(5);
    map { gsl_matrix_set($self->{matrix}, 0, $_, $_) } (0..4);
-   is(gsl_matrix_get_row($vector->{vector}, $self->{matrix}, 0), 0);
-   map { is(gsl_vector_get($vector->{vector}, $_), $_) } (0..4); 
+   is(gsl_matrix_get_row($vector, $self->{matrix}, 0), 0);
+   map { is(gsl_vector_get($vector, $_), $_) } (0..4); 
 }
 
 sub GSL_MATRIX_GET_COL : Tests {
    my $self = shift;
-   my $vector->{vector} = gsl_vector_alloc(5);
+   my $vector = gsl_vector_alloc(5);
    map { gsl_matrix_set($self->{matrix}, $_, 0, $_) } (0..4);
-   is(gsl_matrix_get_col($vector->{vector}, $self->{matrix}, 0), 0);
-   map { is(gsl_vector_get($vector->{vector}, $_), $_) } (0..4); 
+   is(gsl_matrix_get_col($vector, $self->{matrix}, 0), 0);
+   map { is(gsl_vector_get($vector, $_), $_) } (0..4); 
 }
 
 sub GSL_MATRIX_SET_ROW : Tests {
    my $self = shift;
-   my $vector->{vector} = gsl_vector_alloc(5);
-   map { gsl_vector_set($vector->{vector}, $_, $_**2) } (0..4);
-   is(gsl_matrix_set_row($self->{matrix}, 1, $vector->{vector}), 0);
+   my $vector = gsl_vector_alloc(5);
+   map { gsl_vector_set($vector, $_, $_**2) } (0..4);
+   is(gsl_matrix_set_row($self->{matrix}, 1, $vector), 0);
 
    ok_similar( [ map { gsl_matrix_get($self->{matrix}, 1, $_) } (0..4) ],
                [ map { $_ ** 2 } (0..4) ],
@@ -374,9 +374,9 @@ sub GSL_MATRIX_SET_ROW : Tests {
 
 sub GSL_MATRIX_SET_COL : Tests {
    my $self = shift;
-   my $vector->{vector} = gsl_vector_alloc(5);
-   map { gsl_vector_set($vector->{vector}, $_, $_**2) } (0..4);
-   is(gsl_matrix_set_col($self->{matrix}, 1, $vector->{vector}), 0);
+   my $vector = gsl_vector_alloc(5);
+   map { gsl_vector_set($vector, $_, $_**2) } (0..4);
+   is(gsl_matrix_set_col($self->{matrix}, 1, $vector), 0);
 
    ok_similar( [ map { gsl_matrix_get($self->{matrix}, $_, 1) } (0..4) ],
                [ map { $_ ** 2 } (0..4) ],
@@ -389,15 +389,15 @@ sub GSL_MATRIX_FREAD_FWRITE : Tests {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**2) } (0..4); 
    }
 
-   my $fh = fopen("matrix", "w");
+   my $fh = gsl_fopen("matrix", 'w');
    is( gsl_matrix_fwrite($fh, $self->{matrix}), 0);
-   fclose($fh);
+   gsl_fclose($fh);
 
    for my $line (0..4) {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**3) } (0..4); 
    }
 
-   $fh = fopen("matrix", "r");   
+   $fh = gsl_fopen("matrix", 'r');   
    
    is(gsl_matrix_fread($fh, $self->{matrix}), 0);
    for my $line (0..4) {
@@ -406,7 +406,7 @@ sub GSL_MATRIX_FREAD_FWRITE : Tests {
                     [ map { $_**2 } (0..4) ],
                   );
    }
-   fclose($fh); 
+   gsl_fclose($fh); 
 }
 
 sub GSL_MATRIX_FPRINTF_FSCANF : Tests {
@@ -416,7 +416,9 @@ sub GSL_MATRIX_FPRINTF_FSCANF : Tests {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**2) } (0..4); 
    }
 
-   my $fh = fopen("matrix", "w");
+   my $write = is_windows() ? "w + b" : "w";
+   my $read  = is_windows() ? "r + b" : "r";
+   my $fh = fopen("matrix", $write);
    is( gsl_matrix_fprintf($fh, $self->{matrix}, "%f"), 0);
    fclose($fh);
 
@@ -424,7 +426,7 @@ sub GSL_MATRIX_FPRINTF_FSCANF : Tests {
         map { gsl_matrix_set($self->{matrix}, $line, $_, $_**3) } (0..4); 
    }
 
-   $fh = fopen("matrix", "r");   
+   $fh = fopen("matrix", $read);   
    
    is(gsl_matrix_fscanf($fh, $self->{matrix}), 0);
    for my $line (0..4) {
@@ -491,6 +493,9 @@ sub ROW : Tests {
     my $matrix = Math::GSL::Matrix->new(5,5);
     map { gsl_matrix_set($matrix->raw, $_, $_, 5 + $_**2) } (0..4);
     ok_similar( [qw/0 0 9 0 0/] , [$matrix->row(2)->as_list ] );
+    map { gsl_matrix_set($matrix->raw, 0, $_, $_) } (0..4);
+    ok_similar( [qw/0 1 2 3 4/] , [$matrix->row(0)->as_list ] );
+    
 }
 
 sub COL : Tests {
@@ -547,4 +552,17 @@ sub SET_COL_CHAINED : Tests {
  ok_similar([$m->col(2)->as_list], [9,8,7]);
 }
 
+sub GSL_MATRIX_VIEW_ARRAY : Tests {
+ my $array = [8,4,3,7];
+ my $matrix_view = gsl_matrix_view_array ($array, 2,2);
+ ok_similar([map { gsl_matrix_get($matrix_view->{matrix}, 0, $_) } 0..1], [8, 4]);
+ ok_similar([map { gsl_matrix_get($matrix_view->{matrix}, 1, $_) } 0..1], [3, 7]);
+}
+
+sub GSL_MATRIX_VIEW_ARRAY_WITH_TDA : Tests {
+ my $array = [8,4,3,7,5];
+ my $matrix_view = gsl_matrix_view_array_with_tda ($array, 2,2, 3);
+ ok_similar([map { gsl_matrix_get($matrix_view->{matrix}, 0, $_) } 0..1], [8, 4]);
+ ok_similar([map { gsl_matrix_get($matrix_view->{matrix}, 1, $_) } 0..1], [7, 5]);
+}
 1;
