@@ -169,12 +169,12 @@ sub GSL_PERMUTATION_MUL : Tests {
 sub GSL_PERMUTATION_FWRITE_FREAD : Tests {
     my $self = shift;
     gsl_permutation_init($self->{permutation});
-    my $fh = fopen("permutation", "w");
+    my $fh = gsl_fopen("permutation", 'w');
     gsl_permutation_fwrite($fh, $self->{permutation});
     fclose($fh);
 
     my $p = gsl_permutation_alloc(6);
-    $fh = fopen("permutation", "r");
+    $fh = gsl_fopen("permutation", 'r');
     gsl_permutation_fread($fh, $p);
     map { is(gsl_permutation_get($p, $_), $_) } (0..5);
     fclose($fh);
@@ -182,19 +182,19 @@ sub GSL_PERMUTATION_FWRITE_FREAD : Tests {
 
 sub GSL_PERMUTATION_FPRINTF_FSCANF : Tests {
     my $self = shift;
-    my $fh = fopen("permutation", "w");
+    my $fh = gsl_fopen("permutation", 'w');
     gsl_permutation_init($self->{permutation});
-    ok_status( gsl_permutation_fprintf($fh, $self->{permutation}, "%f"), $GSL_SUCCESS);
-    fclose($fh);
+    ok_status( gsl_permutation_fprintf($fh, $self->{permutation}, "%f"));
+    ok_status(gsl_fclose($fh));
 
     local $TODO = "odd error with fscanf";
-    $fh = fopen("permutation", "r");
+    $fh = gsl_fopen("permutation", 'r');
     my $p = gsl_permutation_alloc(6); 
-    #ok_status(gsl_permutation_fscanf($fh, $p), $GSL_SUCCESS); 
+    #ok_status(gsl_permutation_fscanf($fh, $p)); 
     is_deeply( [ map {gsl_permutation_get($p, $_) }  (0..5) ],
                [ 0 .. 5 ],
     );
-    fclose($fh);
+    ok_status(gsl_fclose($fh));
 }
 
 sub NEW: Tests { 
